summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/bookmark_manager_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/views/bookmark_manager_view.h')
-rw-r--r--chrome/browser/views/bookmark_manager_view.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/chrome/browser/views/bookmark_manager_view.h b/chrome/browser/views/bookmark_manager_view.h
index 0a4fede..1bcb1c0 100644
--- a/chrome/browser/views/bookmark_manager_view.h
+++ b/chrome/browser/views/bookmark_manager_view.h
@@ -158,9 +158,11 @@ class BookmarkManagerView : public views::View,
// is no search text.
BookmarkTableModel* CreateSearchTableModel();
// Sets the model of the table and its parent node.
void SetTableModel(BookmarkTableModel* new_table_model,
- BookmarkNode* parent_node);
+ BookmarkNode* parent_node,
+ bool is_search);
// Sets the table's model to the results of CreateSearchTableModel and selects
// the search node in the tree.
@@ -158,9 +158,11 @@ class BookmarkManagerView : public views::View,
// is no search text.
BookmarkTableModel* CreateSearchTableModel();
- // Sets the model of the table and its parent node.
+ // Sets the model of the table and its parent node. If |is_search| is true,
+ // it means the table is showing search results.
void SetTableModel(BookmarkTableModel* new_table_model,